@@ -1,10 +1,6 @@
 """HaVersionLocal class."""
-import logging
-
 from .base import HaVersionBase
 
-_LOGGER = logging.getLogger(__package__)
-
 
 class HaVersionLocal(HaVersionBase):
     """HaVersionLocal class."""
